# Pandas ML Utils

Pandas Machine Learning Utils is intended to help you through your journey of statistical or machine learning models, 
while you never need to leave the world of pandas.

## Installation
Follow the instructions on [https://github.com/KIC/pandas-ml-quant](https://github.com/KIC/pandas-ml-quant)

## Documentation
Check out the notebooks at [https://github.com/KIC/pandas-ml-quant/blob/master/notebooks](https://github.com/KIC/pandas-ml-quant/blob/master/notebooks)

